==> zio-aws-workspacesweb_3-5.17.121.3-sources.jar: zio/aws/workspacesweb/model/ListTrustStoresResponse.scala <==
package zio.aws.workspacesweb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.workspacesweb.model.primitives.PaginationToken
import scala.jdk.CollectionConverters.*
final case class ListTrustStoresResponse(
    nextToken: Option[PaginationToken] = None,
    trustStores: Option[
      Iterable[zio.aws.workspacesweb.model.TrustStoreSummary]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspacesweb.model.ListTrustStoresResponse = {
    import ListTrustStoresResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspacesweb.model.ListTrustStoresResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        trustStores.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.trustStores)
      .build()
  }
  def asReadOnly: zio.aws.workspacesweb.model.ListTrustStoresResponse.ReadOnly =
    zio.aws.workspacesweb.model.ListTrustStoresResponse.wrap(buildAwsValue())
}
object ListTrustStoresResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspacesweb.model.ListTrustStoresResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspacesweb.model.ListTrustStoresResponse =
      zio.aws.workspacesweb.model.ListTrustStoresResponse(
        nextToken.map(value => value),
        trustStores.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Option[PaginationToken]
    def trustStores
        : Option[List[zio.aws.workspacesweb.model.TrustStoreSummary.ReadOnly]]
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getTrustStores: ZIO[Any, AwsError, List[
      zio.aws.workspacesweb.model.TrustStoreSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("trustStores", trustStores)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspacesweb.model.ListTrustStoresResponse
  ) extends zio.aws.workspacesweb.model.ListTrustStoresResponse.ReadOnly {
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value =>
        zio.aws.workspacesweb.model.primitives.PaginationToken(value)
      )
    override val trustStores
        : Option[List[zio.aws.workspacesweb.model.TrustStoreSummary.ReadOnly]] =
      scala
        .Option(impl.trustStores())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.workspacesweb.model.TrustStoreSummary.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspacesweb.model.ListTrustStoresResponse
  ): zio.aws.workspacesweb.model.ListTrustStoresResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-workspacesweb_3-5.20.22.3-sources.jar: zio/aws/workspacesweb/model/ListTrustStoresResponse.scala <==
package zio.aws.workspacesweb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.workspacesweb.model.primitives.PaginationToken
import scala.jdk.CollectionConverters.*
final case class ListTrustStoresResponse(
    nextToken: Optional[PaginationToken] = Optional.Absent,
    trustStores: Optional[
      Iterable[zio.aws.workspacesweb.model.TrustStoreSummary]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspacesweb.model.ListTrustStoresResponse = {
    import ListTrustStoresResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspacesweb.model.ListTrustStoresResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        trustStores.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.trustStores)
      .build()
  }
  def asReadOnly: zio.aws.workspacesweb.model.ListTrustStoresResponse.ReadOnly =
    zio.aws.workspacesweb.model.ListTrustStoresResponse.wrap(buildAwsValue())
}
object ListTrustStoresResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspacesweb.model.ListTrustStoresResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspacesweb.model.ListTrustStoresResponse =
      zio.aws.workspacesweb.model.ListTrustStoresResponse(
        nextToken.map(value => value),
        trustStores.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Optional[PaginationToken]
    def trustStores
        : Optional[List[zio.aws.workspacesweb.model.TrustStoreSummary.ReadOnly]]
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getTrustStores: ZIO[Any, AwsError, List[
      zio.aws.workspacesweb.model.TrustStoreSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("trustStores", trustStores)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspacesweb.model.ListTrustStoresResponse
  ) extends zio.aws.workspacesweb.model.ListTrustStoresResponse.ReadOnly {
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value =>
        zio.aws.workspacesweb.model.primitives.PaginationToken(value)
      )
    override val trustStores: Optional[
      List[zio.aws.workspacesweb.model.TrustStoreSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.trustStores())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.workspacesweb.model.TrustStoreSummary.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspacesweb.model.ListTrustStoresResponse
  ): zio.aws.workspacesweb.model.ListTrustStoresResponse.ReadOnly = new Wrapper(
    impl
  )
}
